<?php

function laecho_fb_meta() {
    global $posts;
    //Site name
    $og_site_name = get_bloginfo('name');
    //Post or Page
    if ( is_single() || is_page() ) {
		//Post data
        $post_data = get_post( $posts[0]->ID, ARRAY_A );
        //Title
        $og_title = laecho_prepare_title($post_data['post_title']);
        //Link
        $og_link = get_permalink($posts[0]->ID);
        //Image Link
        $og_link_image = laecho_thumbnail_link($posts[0]->ID, $post_data['post_content']);
        //Content
        if(!empty($post_data['post_excerpt'])) {
            $og_desc = $post_data['post_excerpt'];
        } else {
            $og_desc = $post_data['post_content'];
			$og_desc = preg_replace("/\[.*?\]/", '', $og_desc);
        }
		$og_desc = laecho_prepare_desc($og_desc);
		$og_desc = laecho_smart_truncate($og_desc, 300);
        //Type
        $og_type = 'article';
    } else {
        //Title
		$og_title = $og_site_name;
        //Link
        $og_link = get_bloginfo('url');
		//Image Link
		$og_link_image = '';
        //Desc
		$og_desc = get_bloginfo('description');
		$og_desc = laecho_prepare_desc($og_desc);
		//Type
        $og_type = "blog";
    }
	//Locale
	$og_locale = get_option('laecho-html-widget-lang-facebooklike');
	//FB App id
	$og_fb_app_id = get_option('laecho-html-fb-app-id');
	//Return
	laecho_build_meta_facebook($og_site_name, $og_title, $og_link, $og_link_image, $og_desc, $og_type, $og_locale, $og_fb_app_id);
	laecho_build_meta_googleplus($og_title, $og_link_image, $og_desc, $og_type);
	return;
}

function laecho_build_meta_facebook($og_site_name, $og_title, $og_link, $og_link_image, $og_desc, $og_type, $og_locale, $og_fb_app_id) {
	$opengraph_meta  = "\n<meta property=\"og:site_name\" content=\"" . $og_site_name . "\" />";    
	$opengraph_meta .= "\n<meta property=\"og:title\" content=\"" . $og_title . "\" />";
	$opengraph_meta .= "\n<meta property=\"og:url\" content=\"" . $og_link . "\" />";
	$opengraph_meta .= "\n<meta property=\"og:image\" content=\"" . $og_link_image . "\" />";
	$opengraph_meta .= "\n<meta property=\"og:description\" content=\"" . $og_desc . "\" />";
	$opengraph_meta .= "\n<meta property=\"og:type\" content=\"". $og_type ."\" />";
	$opengraph_meta .= "\n<meta property=\"og:locale\" content=\"" . $og_locale . "\" />";
	$opengraph_meta .= "\n<meta property=\"fb:app_id\" content=\"" . $og_fb_app_id . "\" />";
	echo "\n<!-- Facebook Open Graph metatags added by WordPress plugin. Get it at: http://www.linksalpha.com/widgets/buttons -->" . $opengraph_meta . "\n<!-- End Facebook Open Graph metatags-->\n";
}

function laecho_build_meta_googleplus($og_title, $og_link_image, $og_desc, $og_type) {
	$opengraph_meta  = "\n<meta itemprop=\"name\"  content=\"" . $og_title . "\" />";
	$opengraph_meta .= "\n<meta itemprop=\"image\" content=\"" . $og_link_image . "\" />";
	$opengraph_meta .= "\n<meta itemprop=\"description\" content=\"" . $og_desc . "\" />";
	echo "\n<!-- Google Plus metatags added by WordPress plugin. Get it at: http://www.linksalpha.com/widgets/buttons -->" . $opengraph_meta . "\n<!-- End Google Plus metatags-->\n";
}

function laecho_html_schema($attr) {
	$laecho_opt_googleplus_page_type = get_option('laecho-html-googleplus-page-type');
	if(!$laecho_opt_googleplus_page_type) {
		$laecho_opt_googleplus_page_type = 'Article';
	}
	$attr .= " xmlns:og=\"http://opengraphprotocol.org/schema/\"";
	$attr .= " xmlns:fb=\"http://www.facebook.com/2008/fbml\"";
	//$attr .= " xmlns:fb=\"http://ogp.me/ns/fb#\">";
	$attr .= " itemscope itemtype=\"http://schema.org/".$laecho_opt_googleplus_page_type."\"";
	return $attr;
}

function laecho_smart_truncate($string, $required_length) {
  $parts = preg_split('/([\s\n\r]+)/', $string, null, PREG_SPLIT_DELIM_CAPTURE);
  $parts_count = count($parts);
  $length = 0;
  $last_part = 0;
  for (; $last_part < $parts_count; ++$last_part) {
    $length += strlen($parts[$last_part]);
    if ($length > $required_length) {break;}
  }
  return implode(array_slice($parts, 0, $last_part));
}

function laecho_prepare_title($title) {
	$title = trim($title);
	$php_version = explode('.', phpversion());
	if(count($php_version) && $php_version[0]>=5) {
		$title = html_entity_decode($title, ENT_QUOTES, 'UTF-8');
	} else {
		$title = html_entity_decode($title, ENT_QUOTES);
	}
	$title = laecho_smart_truncate($title, 300);
	$title = htmlspecialchars($title);
	return $title;
}

function laecho_prepare_desc($text) {
	$text = stripslashes($text);
	$text = strip_tags($text);
	$text = preg_replace('/([\n \t\r]+)/', ' ', $text); 
	$text = preg_replace('/( +)/', ' ', $text);
	$text = laecho_smart_truncate($text, 300);
	$text = trim($text);
	$text = htmlspecialchars($text);
	return $text;
}

function laecho_thumbnail_link($post_id, $post_content) {
    if(function_exists('get_post_thumbnail_id') and function_exists('wp_get_attachment_image_src')) {
        $src = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), 'full');
        if($src) {
            $src = $src[0];
            return $src;
        }
    }
	if(!$post_content) {
		return False;
	}
    if(class_exists("DOMDocument") and function_exists('simplexml_import_dom')) {
		libxml_use_internal_errors(true);
        $doc = new DOMDocument();
        if(!($doc->loadHTML($post_content))){
			return False;
		}
		try {
			$xml = @simplexml_import_dom($doc);
			if($xml) {
				$images = $xml->xpath('//img');
				if(!empty($images)) {
					return $images[0]['src'];
				}
			} else {
				return False;	
			}
		} catch (Exception $e) {
			return False;
		}
    }
    return False;
}
?>